@@ -8,9 +8,7 @@
 #' @param r Hyperparameter used to govern the sensitivity of the locality
 #'   sensitive hash. Corresponds to the width of the hash bucket in the LSH
 #'   algorithm. Increasing values of `r` mean more hash collisions and higher
-#'   sensitivity (fewer false-negatives) at the cost of lower specificity (more
-#'   false-positives and longer run time). For more information, see the
-#'   description in \doi{10.1145/997817.997857}.
+#'   sensitivity (fewer false-negatives) at the cost of lower specificity (more false-positives and longer run time). For more information, see the description in \doi{10.1145/997817.997857}.
 #'
 #' @return A tibble fuzzily-joined on the basis of the variables in `by.` Tries
 #'   to adhere to the same standards as the dplyr-joins, and uses the same
@@ -44,29 +42,64 @@
 #' # keep all observations from X_1, regardless of whether they have a match
 #' euclidean_inner_join(X_1, X_2, by = c("V1", "V2"), threshold = .00005)
 euclidean_anti_join <- function(a, b, by = NULL, threshold = 1, n_bands = 30, band_width = 5, r = .5, progress = FALSE) {
-  euclidean_join_core(a, b, mode = "anti", by = by, threshold = threshold, n_bands = n_bands, progress = progress, band_width = band_width, r = r)
+  fuzzy_join_core(a=a, b=b, by = by,
+            join_func = euclidean_join,
+            mode = "anti",
+            threshold = threshold,
+            n_bands = n_bands,
+            progress = progress,
+            band_width = band_width,
+            r = r)
 }
 
 #' @rdname euclidean-joins
 #' @export
 euclidean_inner_join <- function(a, b, by = NULL, threshold = 1, n_bands = 30, band_width = 5, r = .5, progress = FALSE) {
-  euclidean_join_core(a, b, mode = "inner", by = by, threshold = threshold, n_bands = n_bands, progress = progress, band_width = band_width, r = r)
+  fuzzy_join_core(a=a, b=b, by = by,
+            join_func = euclidean_join,
+            mode = "inner",
+            threshold = threshold,
+            n_bands = n_bands,
+            progress = progress,
+            band_width = band_width,
+            r = r)
 }
 
 #' @rdname euclidean-joins
 #' @export
 euclidean_left_join <- function(a, b, by = NULL, threshold = 1, n_bands = 30, band_width = 5, r = .5, progress = FALSE) {
-  euclidean_join_core(a, b, mode = "left", by = by, threshold = threshold, n_bands = n_bands, progress = progress, band_width = band_width, r = r)
+  fuzzy_join_core(a=a, b=b, by = by,
+            join_func = euclidean_join,
+            mode = "left",
+            threshold = threshold,
+            n_bands = n_bands,
+            progress = progress,
+            band_width = band_width,
+            r = r)
 }
 
 #' @rdname euclidean-joins
 #' @export
 euclidean_right_join <- function(a, b, by = NULL, threshold = 1, n_bands = 30, band_width = 5, r = .5, progress = FALSE) {
-  euclidean_join_core(a, b, mode = "right", by = by, threshold = threshold, n_bands = n_bands, progress = progress, band_width = band_width, r = r)
+  fuzzy_join_core(a=a, b=b, by = by,
+            join_func = euclidean_join,
+            mode = "right",
+            threshold = threshold,
+            n_bands = n_bands,
+            progress = progress,
+            band_width = band_width,
+            r = r)
 }
 
 #' @rdname euclidean-joins
 #' @export
 euclidean_full_join <- function(a, b, by = NULL, threshold = 1, n_bands = 30, band_width = 5, r = .5, progress = FALSE) {
-  euclidean_join_core(a, b, mode = "full", by = by, threshold = threshold, n_bands = n_bands, progress = progress, band_width = band_width, r = r)
+  fuzzy_join_core(a=a, b=b, by = by,
+            join_func = euclidean_join,
+            mode = "full",
+            threshold = threshold,
+            n_bands = n_bands,
+            progress = progress,
+            band_width = band_width,
+            r = r)
 }
